@@ -1,5 +1,3 @@
-import os
-
 import gym
 import numpy as np
 import pygame
@@ -12,6 +10,7 @@ from pettingzoo.utils.conversions import parallel_wrapper_fn
 
 from .ball import Ball
 from .cake_paddle import CakePaddle
+from .manual_policy import ManualPolicy  # noqa: F401
 from .paddle import Paddle
 
 FPS = 15
@@ -26,7 +25,11 @@ def get_flat_shape(width, height, kernel_window_length=2):
 
 
 def original_obs_shape(screen_width, screen_height, kernel_window_length=2):
-    return (int(screen_height * 2 / kernel_window_length), int(screen_width * 2 / (kernel_window_length)), 1)
+    return (
+        int(screen_height * 2 / kernel_window_length),
+        int(screen_width * 2 / (kernel_window_length)),
+        1,
+    )
 
 
 def get_valid_angle(randomizer):
@@ -45,14 +48,33 @@ def get_valid_angle(randomizer):
     d2 = deg_to_rad(0 + hor_deg_range)
 
     angle = 0
-    while ((angle > a1 and angle < b1) or (angle > a2 and angle < b2) or (angle > c1 and angle < d1) or (angle > c2) or (angle < d2)):
+    while (
+        (angle > a1 and angle < b1)
+        or (angle > a2 and angle < b2)
+        or (angle > c1 and angle < d1)
+        or (angle > c2)
+        or (angle < d2)
+    ):
         angle = 2 * np.pi * randomizer.rand()
 
     return angle
 
 
 class CooperativePong:
-    def __init__(self, randomizer, ball_speed=9, left_paddle_speed=12, right_paddle_speed=12, cake_paddle=True, max_cycles=900, bounce_randomness=False, max_reward=100, off_screen_penalty=-10, render_ratio=2, kernel_window_length=2):
+    def __init__(
+        self,
+        randomizer,
+        ball_speed=9,
+        left_paddle_speed=12,
+        right_paddle_speed=12,
+        cake_paddle=True,
+        max_cycles=900,
+        bounce_randomness=False,
+        max_reward=100,
+        off_screen_penalty=-10,
+        render_ratio=2,
+        kernel_window_length=2,
+    ):
         super().__init__()
 
         pygame.init()
@@ -63,18 +85,29 @@ class CooperativePong:
 
         # Display screen
         self.s_width, self.s_height = 960 // render_ratio, 560 // render_ratio
-        self.screen = pygame.Surface((self.s_width, self.s_height))  # (960, 720) # (640, 480) # (100, 200)
+        self.screen = pygame.Surface(
+            (self.s_width, self.s_height)
+        )  # (960, 720) # (640, 480) # (100, 200)
         self.area = self.screen.get_rect()
         self.max_reward = max_reward
         self.off_screen_penalty = off_screen_penalty
 
         # define action and observation spaces
         self.action_space = [gym.spaces.Discrete(3) for _ in range(self.num_agents)]
-        original_shape = original_obs_shape(self.s_width, self.s_height, kernel_window_length=kernel_window_length)
+        original_shape = original_obs_shape(
+            self.s_width, self.s_height, kernel_window_length=kernel_window_length
+        )
         original_color_shape = (original_shape[0], original_shape[1], 3)
-        self.observation_space = [gym.spaces.Box(low=0, high=255, shape=(original_color_shape), dtype=np.uint8) for _ in range(self.num_agents)]
+        self.observation_space = [
+            gym.spaces.Box(
+                low=0, high=255, shape=(original_color_shape), dtype=np.uint8
+            )
+            for _ in range(self.num_agents)
+        ]
         # define the global space of the environment or state
-        self.state_space = gym.spaces.Box(low=0, high=255, shape=((self.s_height, self.s_width, 3)), dtype=np.uint8)
+        self.state_space = gym.spaces.Box(
+            low=0, high=255, shape=((self.s_height, self.s_width, 3)), dtype=np.uint8
+        )
 
         self.renderOn = False
 
@@ -88,12 +121,19 @@ class CooperativePong:
         if cake_paddle:
             self.p1 = CakePaddle(right_paddle_speed, render_ratio=render_ratio)
         else:
-            self.p1 = Paddle((20 // render_ratio, 100 // render_ratio), right_paddle_speed)
+            self.p1 = Paddle(
+                (20 // render_ratio, 100 // render_ratio), right_paddle_speed
+            )
 
         self.agents = ["paddle_0", "paddle_1"]  # list(range(self.num_agents))
 
         # ball
-        self.ball = Ball(randomizer, (20 // render_ratio, 20 // render_ratio), ball_speed, bounce_randomness)
+        self.ball = Ball(
+            randomizer,
+            (20 // render_ratio, 20 // render_ratio),
+            ball_speed,
+            bounce_randomness,
+        )
         self.randomizer = randomizer
 
         self.reinit()
@@ -104,13 +144,16 @@ class CooperativePong:
         self.infos = dict(zip(self.agents, [{}] * len(self.agents)))
         self.score = 0
 
-    def reset(self):
+    def reset(self, seed=None, options=None):
         # reset ball and paddle init conditions
         self.ball.rect.center = self.area.center
         # set the direction to an angle between [0, 2*np.pi)
         angle = get_valid_angle(self.randomizer)
         # angle = deg_to_rad(89)
-        self.ball.speed = [int(self.ball.speed_val * np.cos(angle)), int(self.ball.speed_val * np.sin(angle))]
+        self.ball.speed = [
+            int(self.ball.speed_val * np.cos(angle)),
+            int(self.ball.speed_val * np.sin(angle)),
+        ]
 
         self.p0.rect.midleft = self.area.midleft
         self.p1.rect.midright = self.area.midright
@@ -138,7 +181,7 @@ class CooperativePong:
         self.renderOn = True
         self.draw()
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         if not self.renderOn and mode == "human":
             # sets self.renderOn to true and initializes display
             self.enable_render()
@@ -146,18 +189,22 @@ class CooperativePong:
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
         if mode == "human":
             pygame.display.flip()
-        return np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+        return (
+            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+        )
 
     def observe(self):
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
-        observation = np.rot90(observation, k=3)  # now the obs is laid out as H, W as rows and cols
+        observation = np.rot90(
+            observation, k=3
+        )  # now the obs is laid out as H, W as rows and cols
         observation = np.fliplr(observation)  # laid out in the correct order
         return observation
 
     def state(self):
-        '''
+        """
         Returns an observation of the global environment
-        '''
+        """
         state = pygame.surfarray.pixels3d(self.screen).copy()
         state = np.rot90(state, k=3)
         state = np.fliplr(state)
@@ -223,10 +270,11 @@ parallel_env = parallel_wrapper_fn(env)
 class raw_env(AECEnv, EzPickle):
     # class env(MultiAgentEnv):
     metadata = {
-        'render_modes': ['human', "rgb_array"],
-        'name': "cooperative_pong_v5",
-        'is_parallelizable': True,
-        'render_fps': FPS
+        "render_modes": ["human", "rgb_array"],
+        "name": "cooperative_pong_v5",
+        "is_parallelizable": True,
+        "render_fps": FPS,
+        "has_manual_policy": True,
     }
 
     def __init__(self, **kwargs):
@@ -259,11 +307,14 @@ class raw_env(AECEnv, EzPickle):
 
     # def convert_to_dict(self, list_of_list):
     #     return dict(zip(self.agents, list_of_list))
+
     def seed(self, seed=None):
         self.randomizer, seed = seeding.np_random(seed)
         self.env = CooperativePong(self.randomizer, **self._kwargs)
 
-    def reset(self):
+    def reset(self, seed=None, return_info=False, options=None):
+        if seed is not None:
+            self.seed(seed=seed)
         self.env.reset()
         self.agents = self.possible_agents[:]
         self.agent_selection = self._agent_selector.reset()
@@ -283,7 +334,7 @@ class raw_env(AECEnv, EzPickle):
     def close(self):
         self.env.close()
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         return self.env.render(mode)
 
     def step(self, action):
@@ -291,8 +342,10 @@ class raw_env(AECEnv, EzPickle):
             return self._was_done_step(action)
         agent = self.agent_selection
         if not self.action_spaces[agent].contains(action):
-            raise Exception('Action for agent {} must be in Discrete({}).'
-                            'It is currently {}'.format(agent, self.action_spaces[agent].n, action))
+            raise Exception(
+                "Action for agent {} must be in Discrete({})."
+                "It is currently {}".format(agent, self.action_spaces[agent].n, action)
+            )
 
         self.env.step(action, agent)
         # select next agent and observe
@@ -306,5 +359,6 @@ class raw_env(AECEnv, EzPickle):
         self._cumulative_rewards[agent] = 0
         self._accumulate_rewards()
 
+
 # This was originally created, in full, by Ananth Hari in a different repo, and was
 # added in by J K Terry (which is why they're shown as the creator in the git history)
