@@ -1,5 +1,6 @@
 import os
 import sys
+from itertools import repeat
 
 import numpy as np
 import pygame
@@ -11,8 +12,7 @@ from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector, wrappers
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
-from .manual_control import manual_control
-from .manual_policy import ManualPolicy
+from .manual_policy import ManualPolicy  # noqa: F401
 from .src import constants as const
 from .src.img import get_image
 from .src.players import Archer, Knight
@@ -36,9 +36,10 @@ class raw_env(AECEnv, EzPickle):
 
     metadata = {
         "render_modes": ["human", "rgb_array"],
-        "name": "knights_archers_zombies_v9",
+        "name": "knights_archers_zombies_v10",
         "is_parallelizable": True,
         "render_fps": const.FPS,
+        "has_manual_policy": True,
     }
 
     def __init__(
@@ -46,23 +47,45 @@ class raw_env(AECEnv, EzPickle):
         spawn_rate=20,
         num_archers=2,
         num_knights=2,
+        max_zombies=10,
+        max_arrows=10,
         killable_knights=True,
         killable_archers=True,
         pad_observation=True,
         line_death=False,
         max_cycles=900,
+        vector_state=True,
+        use_typemasks=False,
+        transformer=False,
     ):
         EzPickle.__init__(
             self,
             spawn_rate,
             num_archers,
             num_knights,
+            max_zombies,
+            max_arrows,
             killable_knights,
             killable_archers,
             pad_observation,
             line_death,
             max_cycles,
+            vector_state,
+            use_typemasks,
+            transformer,
         )
+        # variable state space
+        self.transformer = transformer
+
+        # whether we want RGB state or vector state
+        self.vector_state = vector_state
+        # agents + zombies + weapons
+        self.num_tracked = (
+            num_archers + num_knights + max_zombies + num_knights + max_arrows
+        )
+        self.use_typemasks = True if transformer else use_typemasks
+        self.typemask_width = 6
+        self.vector_width = 4 + self.typemask_width if use_typemasks else 4
 
         # Game Status
         self.frames = 0
@@ -80,6 +103,8 @@ class raw_env(AECEnv, EzPickle):
         self.line_death = line_death
         self.num_archers = num_archers
         self.num_knights = num_knights
+        self.max_zombies = max_zombies
+        self.max_arrows = max_arrows
 
         # Represents agents to remove at end of cycle
         self.kill_list = []
@@ -100,23 +125,41 @@ class raw_env(AECEnv, EzPickle):
             self.agent_name_mapping[k_name] = a_count
             a_count += 1
 
+        shape = (
+            [512, 512, 3]
+            if not self.vector_state
+            else [self.num_tracked + 1, self.vector_width + 1]
+        )
+        low = 0 if not self.vector_state else -1.0
+        high = 255 if not self.vector_state else 1.0
+        dtype = np.uint8 if not self.vector_state else np.float64
         self.observation_spaces = dict(
             zip(
                 self.agents,
                 [
-                    Box(low=0, high=255, shape=(512, 512, 3), dtype=np.uint8)
+                    Box(low=low, high=high, shape=shape, dtype=dtype)
                     for _ in enumerate(self.agents)
                 ],
             )
         )
+
         self.action_spaces = dict(
             zip(self.agents, [Discrete(6) for _ in enumerate(self.agents)])
         )
+
+        shape = (
+            [const.SCREEN_HEIGHT, const.SCREEN_WIDTH, 3]
+            if not self.vector_state
+            else [self.num_tracked, self.vector_width]
+        )
+        low = 0 if not self.vector_state else -1.0
+        high = 255 if not self.vector_state else 1.0
+        dtype = np.uint8 if not self.vector_state else np.float64
         self.state_space = Box(
-            low=0,
-            high=255,
-            shape=(const.SCREEN_HEIGHT, const.SCREEN_WIDTH, 3),
-            dtype=np.uint8,
+            low=low,
+            high=high,
+            shape=shape,
+            dtype=dtype,
         )
         self.possible_agents = self.agents
 
@@ -148,45 +191,56 @@ class raw_env(AECEnv, EzPickle):
 
     # Spawn Zombies at Random Location at every 100 iterations
     def spawn_zombie(self):
-        self.zombie_spawn_rate += 1
-        zombie = Zombie(self.np_random)
+        if len(self.zombie_list) < self.max_zombies:
+            self.zombie_spawn_rate += 1
+            zombie = Zombie(self.np_random)
 
-        if self.zombie_spawn_rate >= self.spawn_rate:
-            zombie.rect.x = self.np_random.randint(0, const.SCREEN_WIDTH)
-            zombie.rect.y = 5
+            if self.zombie_spawn_rate >= self.spawn_rate:
+                zombie.rect.x = self.np_random.random_integers(0, const.SCREEN_WIDTH)
+                zombie.rect.y = 5
 
-            self.zombie_list.add(zombie)
-            self.zombie_spawn_rate = 0
+                self.zombie_list.add(zombie)
+                self.zombie_spawn_rate = 0
 
-    # Spawn Swords for Players
-    def action_sword(self, action, agent):
-        if (
-            action == 5
-            and agent.is_knight
-            and agent.weapon_timeout > const.SWORD_TIMEOUT
-        ):
-            # make sure that the current knight doesn't have a sword already
-            for sword in self.sword_list:
-                if sword.knight == agent:
-                    return
+    # actuate weapons
+    def action_weapon(self, action, agent):
+        if action == 5:
+            if agent.is_knight:
+                if agent.weapon_timeout > const.SWORD_TIMEOUT:
+                    # make sure that the current knight doesn't have a sword already
+                    if len(agent.weapons) == 0:
+                        agent.weapons.add(Sword(agent))
 
-            self.sword_list.add(Sword(agent))
+            if agent.is_archer:
+                if agent.weapon_timeout > const.ARROW_TIMEOUT:
+                    # make sure that the screen has less arrows than allowable
+                    if self.num_active_arrows < self.max_arrows:
+                        agent.weapons.add(Arrow(agent))
 
-    # Spawn Arrows for Players
-    def action_arrow(self, action, agent):
-        if (
-            action == 5
-            and agent.is_archer
-            and agent.weapon_timeout > const.ARROW_TIMEOUT
-        ):
-            self.arrow_list.add(Arrow(agent))
+    # move weapons
+    def update_weapons(self):
+        for agent in self.agent_list:
+            for weapon in list(agent.weapons):
+                weapon.update()
 
-    # Stab the Sword
-    def move_sword(self):
-        for sword in self.sword_list:
-            sword_active = sword.update()
-            if not sword_active:
-                self.sword_list.remove(sword)
+                if not weapon.is_active:
+                    agent.weapons.remove(weapon)
+
+    @property
+    def num_active_arrows(self):
+        num_arrows = 0
+        for agent in self.agent_list:
+            if agent.is_archer:
+                num_arrows += len(agent.weapons)
+        return num_arrows
+
+    @property
+    def num_active_swords(self):
+        num_swords = 0
+        for agent in self.agent_list:
+            if agent.is_knight:
+                num_swords += len(agent.weapons)
+        return num_swords
 
     # Zombie Kills the Knight (also remove the sword)
     def zombit_hit_knight(self):
@@ -197,13 +251,12 @@ class raw_env(AECEnv, EzPickle):
 
             for knight in zombie_knight_list:
                 knight.alive = False
-                self.knight_list.remove(knight)
+                knight.weapons.empty()
+
                 if knight.agent_name not in self.kill_list:
                     self.kill_list.append(knight.agent_name)
 
-                for sword in self.sword_list:
-                    if sword.knight == knight:
-                        self.sword_list.remove(sword)
+                self.knight_list.remove(knight)
 
     # Zombie Kills the Archer
     def zombie_hit_archer(self):
@@ -220,85 +273,216 @@ class raw_env(AECEnv, EzPickle):
 
     # Zombie Kills the Sword
     def sword_hit(self):
-        for sword in self.sword_list:
-            zombie_sword_list = pygame.sprite.spritecollide(
-                sword, self.zombie_list, True
-            )
+        for knight in self.knight_list:
+            for sword in knight.weapons:
+                zombie_sword_list = pygame.sprite.spritecollide(
+                    sword, self.zombie_list, True
+                )
 
-            # For each zombie hit, remove the sword and add to the score
-            for zombie in zombie_sword_list:
-                self.zombie_list.remove(zombie)
-                sword.knight.score += 1
+                for zombie in zombie_sword_list:
+                    self.zombie_list.remove(zombie)
+                    sword.knight.score += 1
 
     # Zombie Kills the Arrow
     def arrow_hit(self):
-        for arrow in self.arrow_list:
-            zombie_arrow_list = pygame.sprite.spritecollide(
-                arrow, self.zombie_list, True
-            )
+        for agent in self.agent_list:
+            if agent.is_archer:
+                for arrow in list(agent.weapons):
+                    zombie_arrow_list = pygame.sprite.spritecollide(
+                        arrow, self.zombie_list, True
+                    )
 
-            # For each zombie hit, remove the arrow, zombie and add to the score
-            for zombie in zombie_arrow_list:
-                self.arrow_list.remove(arrow)
-                self.zombie_list.remove(zombie)
-                # score += 1
-                arrow.archer.score += 1
-
-            # Remove the arrow if it flies up off the screen
-            if arrow.rect.y < 0:
-                self.arrow_list.remove(arrow)
+                    # For each zombie hit, remove the arrow, zombie and add to the score
+                    for zombie in zombie_arrow_list:
+                        agent.weapons.remove(arrow)
+                        self.zombie_list.remove(zombie)
+                        arrow.archer.score += 1
 
     # Zombie reaches the End of the Screen
     def zombie_endscreen(self, run, zombie_list):
         for zombie in zombie_list:
-            if zombie.rect.y > 690:
+            if zombie.rect.y > const.SCREEN_HEIGHT - const.ZOMBIE_Y_SPEED:
                 run = False
         return run
 
     # Zombie Kills all Players
-    def zombie_all_players(self, knight_list, archer_list, run):
+    def zombie_all_players(self, run, knight_list, archer_list):
         if not knight_list and not archer_list:
             run = False
         return run
 
     def observe(self, agent):
-        screen = pygame.surfarray.pixels3d(self.WINDOW)
+        if not self.vector_state:
+            screen = pygame.surfarray.pixels3d(self.WINDOW)
 
-        i = self.agent_name_mapping[agent]
-        agent_obj = self.agent_list[i]
-        agent_position = (agent_obj.rect.x, agent_obj.rect.y)
+            i = self.agent_name_mapping[agent]
+            agent_obj = self.agent_list[i]
+            agent_position = (agent_obj.rect.x, agent_obj.rect.y)
+
+            if not agent_obj.alive:
+                cropped = np.zeros((512, 512, 3), dtype=np.uint8)
+            else:
+                min_x = agent_position[0] - 256
+                max_x = agent_position[0] + 256
+                min_y = agent_position[1] - 256
+                max_y = agent_position[1] + 256
+                lower_y_bound = max(min_y, 0)
+                upper_y_bound = min(max_y, const.SCREEN_HEIGHT)
+                lower_x_bound = max(min_x, 0)
+                upper_x_bound = min(max_x, const.SCREEN_WIDTH)
+                startx = lower_x_bound - min_x
+                starty = lower_y_bound - min_y
+                endx = 512 + upper_x_bound - max_x
+                endy = 512 + upper_y_bound - max_y
+                cropped = np.zeros_like(self.observation_spaces[agent].low)
+                cropped[startx:endx, starty:endy, :] = screen[
+                    lower_x_bound:upper_x_bound, lower_y_bound:upper_y_bound, :
+                ]
+
+            return np.swapaxes(cropped, 1, 0)
 
-        if not agent_obj.alive:
-            cropped = np.zeros((512, 512, 3), dtype=np.uint8)
         else:
-            min_x = agent_position[0] - 256
-            max_x = agent_position[0] + 256
-            min_y = agent_position[1] - 256
-            max_y = agent_position[1] + 256
-            lower_y_bound = max(min_y, 0)
-            upper_y_bound = min(max_y, const.SCREEN_HEIGHT)
-            lower_x_bound = max(min_x, 0)
-            upper_x_bound = min(max_x, const.SCREEN_WIDTH)
-            startx = lower_x_bound - min_x
-            starty = lower_y_bound - min_y
-            endx = 512 + upper_x_bound - max_x
-            endy = 512 + upper_y_bound - max_y
-            cropped = np.zeros_like(self.observation_spaces[agent].low)
-            cropped[startx:endx, starty:endy, :] = screen[
-                lower_x_bound:upper_x_bound, lower_y_bound:upper_y_bound, :
-            ]
+            # get the agent
+            agent = self.agent_list[self.agent_name_mapping[agent]]
 
-        return np.swapaxes(cropped, 1, 0)
+            # get the agent position
+            agent_state = agent.vector_state
+            agent_pos = np.expand_dims(agent_state[0:2], axis=0)
+
+            # get vector state of everything
+            vector_state = self.get_vector_state()
+            state = vector_state[:, -4:]
+            is_dead = np.sum(np.abs(state), axis=1) == 0.0
+            all_ids = vector_state[:, :-4]
+            all_pos = state[:, 0:2]
+            all_ang = state[:, 2:4]
+
+            # get relative positions
+            rel_pos = all_pos - agent_pos
+
+            # get norm of relative distance
+            norm_pos = np.linalg.norm(rel_pos, axis=1, keepdims=True) / np.sqrt(2)
+
+            # kill dead things
+            all_ids[is_dead] *= 0
+            all_ang[is_dead] *= 0
+            rel_pos[is_dead] *= 0
+            norm_pos[is_dead] *= 0
+
+            # combine the typemasks, positions and angles
+            state = np.concatenate([all_ids, norm_pos, rel_pos, all_ang], axis=-1)
+
+            # get the agent state as absolute vector
+            # typemask is one longer to also include norm_pos
+            if self.use_typemasks:
+                typemask = np.zeros(self.typemask_width + 1)
+                typemask[-2] = 1.0
+            else:
+                typemask = np.array([0.0])
+            agent_state = agent.vector_state
+            agent_state = np.concatenate([typemask, agent_state], axis=0)
+            agent_state = np.expand_dims(agent_state, axis=0)
+
+            # prepend agent state to the observation
+            state = np.concatenate([agent_state, state], axis=0)
+
+            return state
 
     def state(self):
         """
         Returns an observation of the global environment
         """
-        state = pygame.surfarray.pixels3d(self.WINDOW).copy()
-        state = np.rot90(state, k=3)
-        state = np.fliplr(state)
+        if not self.vector_state:
+            state = pygame.surfarray.pixels3d(self.WINDOW).copy()
+            state = np.rot90(state, k=3)
+            state = np.fliplr(state)
+        else:
+            state = self.get_vector_state()
+
         return state
 
+    def get_vector_state(self):
+        state = []
+        typemask = np.array([])
+
+        # handle agents
+        for agent_name in self.possible_agents:
+            if agent_name not in self.dead_agents:
+                agent = self.agent_list[self.agent_name_mapping[agent_name]]
+
+                if self.use_typemasks:
+                    typemask = np.zeros(self.typemask_width)
+                    if agent.is_archer:
+                        typemask[1] = 1.0
+                    elif agent.is_knight:
+                        typemask[2] = 1.0
+
+                vector = np.concatenate((typemask, agent.vector_state), axis=0)
+                state.append(vector)
+            else:
+                if not self.transformer:
+                    state.append(np.zeros(self.vector_width))
+
+        # handle swords
+        for agent in self.agent_list:
+            if agent.is_knight:
+                for sword in agent.weapons:
+                    if self.use_typemasks:
+                        typemask = np.zeros(self.typemask_width)
+                        typemask[4] = 1.0
+
+                    vector = np.concatenate((typemask, sword.vector_state), axis=0)
+                    state.append(vector)
+
+        # handle empty swords
+        if not self.transformer:
+            state.extend(
+                repeat(
+                    np.zeros(self.vector_width),
+                    self.num_knights - self.num_active_swords,
+                )
+            )
+
+        # handle arrows
+        for agent in self.agent_list:
+            if agent.is_archer:
+                for arrow in agent.weapons:
+                    if self.use_typemasks:
+                        typemask = np.zeros(self.typemask_width)
+                        typemask[3] = 1.0
+
+                    vector = np.concatenate((typemask, arrow.vector_state), axis=0)
+                    state.append(vector)
+
+        # handle empty arrows
+        if not self.transformer:
+            state.extend(
+                repeat(
+                    np.zeros(self.vector_width),
+                    self.max_arrows - self.num_active_arrows,
+                )
+            )
+
+        # handle zombies
+        for zombie in self.zombie_list:
+            if self.use_typemasks:
+                typemask = np.zeros(self.typemask_width)
+                typemask[0] = 1.0
+
+            vector = np.concatenate((typemask, zombie.vector_state), axis=0)
+            state.append(vector)
+
+        # handle empty zombies
+        if not self.transformer:
+            state.extend(
+                repeat(
+                    np.zeros(self.vector_width),
+                    self.max_zombies - len(self.zombie_list),
+                )
+            )
+
+        return np.stack(state, axis=0)
+
     def step(self, action):
         # check if the particular agent is done
         if self.dones[self.agent_selection]:
@@ -324,27 +508,25 @@ class raw_env(AECEnv, EzPickle):
             if agent in self.archer_list:
                 self.archer_list.remove(agent)
             else:
+                agent.weapons.empty()
                 self.knight_list.remove(agent)
             self.kill_list.append(agent.agent_name)
 
-        # actuate the sword
-        self.action_sword(action, agent)
-
-        # actuate the arrow
-        self.action_arrow(action, agent)
+        # actuate the weapon if necessary
+        self.action_weapon(action, agent)
 
         # Do these things once per cycle
         if self._agent_selector.is_last():
 
-            # Stab the Sword
-            self.move_sword()
-
-            # Zombie Kills the Arrow
-            self.arrow_hit()
+            # Update the weapons
+            self.update_weapons()
 
             # Zombie Kills the Sword
             self.sword_hit()
 
+            # Zombie Kills the Arrow
+            self.arrow_hit()
+
             # Zombie Kills the Archer
             if self.killable_archers:
                 self.zombie_hit_archer()
@@ -357,10 +539,6 @@ class raw_env(AECEnv, EzPickle):
             for zombie in self.zombie_list:
                 zombie.update()
 
-            # update some arrows
-            for arrow in self.arrow_list:
-                arrow.update()
-
             # Spawning Zombies at Random Location at every 100 iterations
             self.spawn_zombie()
 
@@ -419,8 +597,8 @@ class raw_env(AECEnv, EzPickle):
 
         # draw all the sprites
         self.zombie_list.draw(self.WINDOW)
-        self.arrow_list.draw(self.WINDOW)
-        self.sword_list.draw(self.WINDOW)
+        for agent in self.agent_list:
+            agent.weapons.draw(self.WINDOW)
         self.archer_list.draw(self.WINDOW)
         self.knight_list.draw(self.WINDOW)
 
@@ -451,7 +629,7 @@ class raw_env(AECEnv, EzPickle):
         self.run = self.zombie_endscreen(self.run, self.zombie_list)
 
         # Zombie Kills all Players
-        self.run = self.zombie_all_players(self.knight_list, self.archer_list, self.run)
+        self.run = self.zombie_all_players(self.run, self.knight_list, self.archer_list)
 
     def reinit(self):
         # Dictionaries for holding new players and their weapons
@@ -466,8 +644,6 @@ class raw_env(AECEnv, EzPickle):
 
         # Creating Sprite Groups
         self.zombie_list = pygame.sprite.Group()
-        self.arrow_list = pygame.sprite.Group()
-        self.sword_list = pygame.sprite.Group()
         self.archer_list = pygame.sprite.Group()
         self.knight_list = pygame.sprite.Group()
 
@@ -515,7 +691,9 @@ class raw_env(AECEnv, EzPickle):
         self.draw()
         self.frames = 0
 
-    def reset(self):
+    def reset(self, seed=None, return_info=False, options=None):
+        if seed is not None:
+            self.seed(seed=seed)
         self.has_reset = True
         self.agents = self.possible_agents
         self._agent_selector.reinit(self.agents)
