@@ -1,5 +1,3 @@
-import os
-
 import numpy as np
 import pygame
 
@@ -19,10 +17,9 @@ def manual_control(**kwargs):
 
     while not done:
         clock.tick(const.FPS)
-        agent_actions = (
-            [np.array([0, 0, 0], dtype=np.float32) for _ in range(const.NUM_PROSPECTORS)]
-            + [np.array([0, 0], dtype=np.float32) for _ in range(const.NUM_BANKERS)]
-        )
+        agent_actions = [
+            np.array([0, 0, 0], dtype=np.float32) for _ in range(const.NUM_PROSPECTORS)
+        ] + [np.array([0, 0], dtype=np.float32) for _ in range(const.NUM_BANKERS)]
         for event in pygame.event.get():
             # Use left/right arrow keys to switch between agents
             # Use WASD to control bankers
