@@ -24,11 +24,11 @@ def invert_y(points):
 
 
 def rand_pos(sprite, rng):
-    x = rng.randint(100, const.SCREEN_WIDTH - 100)
+    x = rng.integers(100, const.SCREEN_WIDTH - 100)
     if sprite == "banker":
-        return x, rng.randint(170, 300)
+        return x, rng.integers(170, 300)
     elif sprite == "prospector":
-        return x, rng.randint(350, const.SCREEN_HEIGHT - (const.WATER_HEIGHT + 30))
+        return x, rng.integers(350, const.SCREEN_HEIGHT - (const.WATER_HEIGHT + 30))
 
 
 def normalize_angle(angle):
