@@ -1,13 +1,6 @@
-import random
-
-import numpy as np
-import rlcard
-from gym import spaces
 from rlcard.utils.utils import print_card
 
-from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
-from pettingzoo.utils.agent_selector import agent_selector
 
 from .rlcard_base import RLCardBase
 
@@ -33,12 +26,14 @@ class raw_env(RLCardBase):
     def __init__(self, num_players=2):
         super().__init__("leduc-holdem", num_players, (36,))
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
             print(f"\n=============== {player}'s Hand ===============")
-            print_card(state['hand'])
-            print("\n{}'s Chips: {}".format(player, state['my_chips']))
-        print('\n================= Public Cards =================')
-        print_card(state['public_card']) if state['public_card'] is not None else print('No public cards.')
-        print('\n')
+            print_card(state["hand"])
+            print("\n{}'s Chips: {}".format(player, state["my_chips"]))
+        print("\n================= Public Cards =================")
+        print_card(state["public_card"]) if state["public_card"] is not None else print(
+            "No public cards."
+        )
+        print("\n")
