@@ -1,10 +1,3 @@
-import random
-
-import numpy as np
-import rlcard
-from gym import spaces
-
-from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
 
 from .rlcard_base import RLCardBase
@@ -31,12 +24,21 @@ class raw_env(RLCardBase):
     def __init__(self):
         super().__init__("mahjong", 4, (6, 34, 4))
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
             print(f"\n======== {player}'s Hand ========")
-            print(', '.join([c.get_str() for c in state['current_hand']]))
-            print(f"\n{player}'s Piles: ", ', '.join([c.get_str() for pile in state['players_pile'][self._name_to_int(player)] for c in pile]))
+            print(", ".join([c.get_str() for c in state["current_hand"]]))
+            print(
+                f"\n{player}'s Piles: ",
+                ", ".join(
+                    [
+                        c.get_str()
+                        for pile in state["players_pile"][self._name_to_int(player)]
+                        for c in pile
+                    ]
+                ),
+            )
         print("\n======== Tiles on Table ========")
-        print(', '.join([c.get_str() for c in state['table']]))
-        print('\n')
+        print(", ".join([c.get_str() for c in state["table"]]))
+        print("\n")
