@@ -1,5 +1,3 @@
-import warnings
-
 import numpy as np
 from gym import spaces
 
@@ -34,14 +32,21 @@ class raw_env(AECEnv):
         self.possible_agents = self.agents[:]
 
         self.action_spaces = {i: spaces.Discrete(9) for i in self.agents}
-        self.observation_spaces = {i: spaces.Dict({
-                                        'observation': spaces.Box(low=0, high=1, shape=(3, 3, 2), dtype=np.int8),
-                                        'action_mask': spaces.Box(low=0, high=1, shape=(9,), dtype=np.int8)
-                                  }) for i in self.agents}
+        self.observation_spaces = {
+            i: spaces.Dict(
+                {
+                    "observation": spaces.Box(
+                        low=0, high=1, shape=(3, 3, 2), dtype=np.int8
+                    ),
+                    "action_mask": spaces.Box(low=0, high=1, shape=(9,), dtype=np.int8),
+                }
+            )
+            for i in self.agents
+        }
 
         self.rewards = {i: 0 for i in self.agents}
         self.dones = {i: False for i in self.agents}
-        self.infos = {i: {'legal_moves': list(range(0, 9))} for i in self.agents}
+        self.infos = {i: {"legal_moves": list(range(0, 9))} for i in self.agents}
 
         self._agent_selector = agent_selector(self.agents)
         self.agent_selection = self._agent_selector.reset()
@@ -67,11 +72,11 @@ class raw_env(AECEnv):
         observation = np.stack([cur_p_board, opp_p_board], axis=2).astype(np.int8)
         legal_moves = self._legal_moves() if agent == self.agent_selection else []
 
-        action_mask = np.zeros(9, 'int8')
+        action_mask = np.zeros(9, "int8")
         for i in legal_moves:
             action_mask[i] = 1
 
-        return {'observation': observation, 'action_mask': action_mask}
+        return {"observation": observation, "action_mask": action_mask}
 
     def observation_space(self, agent):
         return self.observation_spaces[agent]
@@ -87,7 +92,7 @@ class raw_env(AECEnv):
         if self.dones[self.agent_selection]:
             return self._was_done_step(action)
         # check if input action is a valid move (0 == empty spot)
-        assert (self.board.squares[action] == 0), "played illegal move"
+        assert self.board.squares[action] == 0, "played illegal move"
         # play turn
         self.board.play_turn(self.agents.index(self.agent_selection), action)
 
@@ -120,7 +125,7 @@ class raw_env(AECEnv):
 
         self._accumulate_rewards()
 
-    def reset(self):
+    def reset(self, seed=None, return_info=False, options=None):
         # reset environment
         self.board = Board()
 
@@ -134,14 +139,14 @@ class raw_env(AECEnv):
         self._agent_selector.reset()
         self.agent_selection = self._agent_selector.reset()
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         def getSymbol(input):
             if input == 0:
-                return '-'
+                return "-"
             elif input == 1:
-                return 'X'
+                return "X"
             else:
-                return 'O'
+                return "O"
 
         board = list(map(getSymbol, self.board.squares))
 
