@@ -1,5 +1,3 @@
-import os
-
 import numpy as np
 import pygame
 from gym.utils import EzPickle
@@ -8,7 +6,7 @@ from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector, wrappers
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
-from .manual_control import manual_control
+from .manual_policy import ManualPolicy  # noqa: F401
 from .pursuit_base import Pursuit as _env
 
 
@@ -27,8 +25,9 @@ class raw_env(AECEnv, EzPickle):
     metadata = {
         "render_modes": ["human", "rgb_array"],
         "name": "pursuit_v4",
-        'is_parallelizable': True,
-        'render_fps': 5,
+        "is_parallelizable": True,
+        "render_fps": 5,
+        "has_manual_policy": True,
     }
 
     def __init__(self, *args, **kwargs):
@@ -49,7 +48,9 @@ class raw_env(AECEnv, EzPickle):
     def seed(self, seed=None):
         self.env.seed(seed)
 
-    def reset(self):
+    def reset(self, seed=None, return_info=False, options=None):
+        if seed is not None:
+            self.seed(seed=seed)
         self.steps = 0
         self.agents = self.possible_agents[:]
         self.rewards = dict(zip(self.agents, [(0) for _ in self.agents]))
