@@ -1,9 +1,4 @@
-import copy
-import itertools
-import warnings
-
 import gym
-import numpy as np
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
@@ -47,8 +42,8 @@ class raw_env(AECEnv):
 
     def add_type(self):
         type_id = len(self.types)
-        num_actions = self.np_random.randint(3, 10)
-        obs_size = self.np_random.randint(10, 50)
+        num_actions = self.np_random.random_integers(3, 10)
+        obs_size = self.np_random.random_integers(10, 50)
         obs_space = gym.spaces.Box(low=0, high=1, shape=(obs_size,))
         act_space = gym.spaces.Discrete(num_actions)
         new_type = f"type{type_id}"
@@ -69,7 +64,9 @@ class raw_env(AECEnv):
         self.infos[agent] = {}
         return agent
 
-    def reset(self):
+    def reset(self, seed=None, return_info=False, options=None):
+        if seed is not None:
+            self.seed(seed=seed)
         self.agents = []
         self.rewards = {}
         self._cumulative_rewards = {}
