@@ -19,7 +19,7 @@ def calc_hash(new_env, rand_issue, max_env_iters):
     cur_hashes = []
     sampler = random.Random(42)
     for i in range(3):
-        new_env.reset()
+        new_env.reset(seed=i)
         for j in range(rand_issue + 1):
             random.randint(0, 1000)
             np.random.normal(size=100)
@@ -27,8 +27,8 @@ def calc_hash(new_env, rand_issue, max_env_iters):
             obs, rew, done, info = new_env.last()
             if done:
                 action = None
-            elif isinstance(obs, dict) and 'action_mask' in obs:
-                action = sampler.choice(np.flatnonzero(obs['action_mask']))
+            elif isinstance(obs, dict) and "action_mask" in obs:
+                action = sampler.choice(np.flatnonzero(obs["action_mask"]))
             else:
                 action = new_env.action_space(agent).sample()
             new_env.step(action)
@@ -40,23 +40,23 @@ def calc_hash(new_env, rand_issue, max_env_iters):
 
 
 def seed_action_spaces(env):
-    if hasattr(env, 'possible_agents'):
+    if hasattr(env, "possible_agents"):
         for i, agent in enumerate(env.possible_agents):
             env.action_space(agent).seed(42 + i)
 
 
 def check_environment_deterministic(env1, env2, num_cycles):
-    '''
+    """
     env1 and env2 should be seeded environments
 
     returns a bool: true if env1 and env2 execute the same way
-    '''
+    """
 
     # seeds action space so that actions are deterministic
     seed_action_spaces(env1)
     seed_action_spaces(env2)
 
-    num_agents = max(1, len(getattr(env1, 'possible_agents', [])))
+    num_agents = max(1, len(getattr(env1, "possible_agents", [])))
 
     # checks deterministic behavior if seed is set
     hashes = []
@@ -83,14 +83,10 @@ def hash_obsevation(obs):
 
 def test_environment_reset_deterministic(env1, num_cycles):
     seed_action_spaces(env1)
-    env1.seed(42)
-    env1.reset()
     hash1 = calc_hash(env1, 1, num_cycles)
     seed_action_spaces(env1)
-    env1.seed(42)
-    env1.reset()
     hash2 = calc_hash(env1, 2, num_cycles)
-    assert hash1 == hash2, "environments kept state after seed(42) and reset()"
+    assert hash1 == hash2, "environments kept state after and reset(seed)"
 
 
 def seed_test(env_constructor, num_cycles=10, test_kept_state=True):
@@ -98,12 +94,10 @@ def seed_test(env_constructor, num_cycles=10, test_kept_state=True):
     if test_kept_state:
         test_environment_reset_deterministic(env1, num_cycles)
     env2 = env_constructor()
-    base_seed = 42
-    env1.seed(base_seed)
-    env2.seed(base_seed)
 
-    assert check_environment_deterministic(env1, env2, num_cycles), \
-        ("The environment gives different results on multiple runs when initialized with the same seed. This is usually a sign that you are using np.random or random modules directly, which uses a global random state.")
+    assert check_environment_deterministic(
+        env1, env2, num_cycles
+    ), "The environment gives different results on multiple runs when initialized with the same seed. This is usually a sign that you are using np.random or random modules directly, which uses a global random state."
 
 
 def parallel_seed_test(parallel_env_fn, num_cycles=10, test_kept_state=True):
