@@ -1,7 +1,8 @@
-class agent_selector():
-    '''
-        Outputs an agent in the given order whenever agent_select is called. Can reinitialize to a new order
-    '''
+class agent_selector:
+    """
+    Outputs an agent in the given order whenever agent_select is called. Can reinitialize to a new order
+    """
+
     def __init__(self, agent_order):
         self.reinit(agent_order)
 
@@ -20,9 +21,9 @@ class agent_selector():
         return self.selected_agent
 
     def is_last(self):
-        '''
+        """
         Does not work as expected if you change the order
-        '''
+        """
         return self.selected_agent == self.agent_order[-1]
 
     def is_first(self):
@@ -32,4 +33,8 @@ class agent_selector():
         if not isinstance(other, agent_selector):
             return NotImplemented
 
-        return self.agent_order == other.agent_order and self._current_agent == other._current_agent and self.selected_agent == other.selected_agent
+        return (
+            self.agent_order == other.agent_order
+            and self._current_agent == other._current_agent
+            and self.selected_agent == other.selected_agent
+        )
