@@ -4,14 +4,14 @@ import numpy as np
 
 
 def average_total_reward(env, max_episodes=100, max_steps=10000000000):
-    '''
+    """
     Runs an env object with random actions until either max_episodes or
     max_steps is reached. Calculates the average total reward over the
     episodes.
 
     Reward is summed across all agents, making it unsuited for use in zero-sum
     games.
-    '''
+    """
     total_reward = 0
     total_steps = 0
     done = False
@@ -27,8 +27,8 @@ def average_total_reward(env, max_episodes=100, max_steps=10000000000):
             total_steps += 1
             if done:
                 action = None
-            elif isinstance(obs, dict) and 'action_mask' in obs:
-                action = random.choice(np.flatnonzero(obs['action_mask']))
+            elif isinstance(obs, dict) and "action_mask" in obs:
+                action = random.choice(np.flatnonzero(obs["action_mask"]))
             else:
                 action = env.action_space(agent).sample()
             env.step(action)
