@@ -1,11 +1,9 @@
 import io
 import sys
 
-import numpy as np
-
 
 class capture_stdout:
-    '''
+    """
     usage:
 
     with capture_stdout() as var:
@@ -13,7 +11,8 @@ class capture_stdout:
 
         # value of var will be "hithere"
         data = var.getvalue()
-    '''
+    """
+
     def __init__(self):
         self.old_stdout = None
 
