@@ -12,6 +12,7 @@ def parallel_wrapper_fn(env_fn):
         env = env_fn(**kwargs)
         env = aec_to_parallel_wrapper(env)
         return env
+
     return par_fn
 
 
@@ -41,24 +42,29 @@ def turn_based_aec_to_parallel(aec_env):
 
 
 def to_parallel(aec_env):
-    warnings.warn("The `to_parallel` function is deprecated. Use the `aec_to_parallel` function instead.")
+    warnings.warn(
+        "The `to_parallel` function is deprecated. Use the `aec_to_parallel` function instead."
+    )
     return aec_to_parallel(aec_env)
 
 
 def from_parallel(par_env):
-    warnings.warn("The `from_parallel` function is deprecated. Use the `parallel_to_aec` function instead.")
+    warnings.warn(
+        "The `from_parallel` function is deprecated. Use the `parallel_to_aec` function instead."
+    )
     return parallel_to_aec(par_env)
 
 
 class aec_to_parallel_wrapper(ParallelEnv):
     def __init__(self, aec_env):
-        assert aec_env.metadata.get('is_parallelizable', False), \
-            "Converting from an AEC environment to a parallel environment " \
-            "with the to_parallel wrapper is not generally safe " \
-            "(the AEC environment should only update once at the end " \
-            "of each cycle). If you have confirmed that your AEC environment " \
-            "can be converted in this way, then please set the `is_parallelizable` "\
+        assert aec_env.metadata.get("is_parallelizable", False), (
+            "Converting from an AEC environment to a parallel environment "
+            "with the to_parallel wrapper is not generally safe "
+            "(the AEC environment should only update once at the end "
+            "of each cycle). If you have confirmed that your AEC environment "
+            "can be converted in this way, then please set the `is_parallelizable` "
             "key in your metadata to True"
+        )
 
         self.aec_env = aec_env
 
@@ -77,19 +83,29 @@ class aec_to_parallel_wrapper(ParallelEnv):
 
     @property
     def observation_spaces(self):
-        warnings.warn("The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead.")
+        warnings.warn(
+            "The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead."
+        )
         try:
-            return {agent: self.observation_space(agent) for agent in self.possible_agents}
-        except AttributeError:
-            raise AttributeError("The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead")
+            return {
+                agent: self.observation_space(agent) for agent in self.possible_agents
+            }
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead"
+            ) from e
 
     @property
     def action_spaces(self):
-        warnings.warn("The `action_spaces` dictionary is deprecated. Use the `action_space` function instead.")
+        warnings.warn(
+            "The `action_spaces` dictionary is deprecated. Use the `action_space` function instead."
+        )
         try:
             return {agent: self.action_space(agent) for agent in self.possible_agents}
-        except AttributeError:
-            raise AttributeError("The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead")
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead"
+            ) from e
 
     def observation_space(self, agent):
         return self.aec_env.observation_space(agent)
@@ -101,14 +117,20 @@ class aec_to_parallel_wrapper(ParallelEnv):
     def unwrapped(self):
         return self.aec_env.unwrapped
 
-    def seed(self, seed=None):
-        return self.aec_env.seed(seed)
-
-    def reset(self):
-        self.aec_env.reset()
+    def reset(self, seed=None, return_info=False, options=None):
+        self.aec_env.reset(seed=seed, return_info=return_info, options=options)
         self.agents = self.aec_env.agents[:]
-        observations = {agent: self.aec_env.observe(agent) for agent in self.aec_env.agents if not self.aec_env.dones[agent]}
-        return observations
+        observations = {
+            agent: self.aec_env.observe(agent)
+            for agent in self.aec_env.agents
+            if not self.aec_env.dones[agent]
+        }
+
+        if not return_info:
+            return observations
+        else:
+            infos = dict(**self.aec_env.infos)
+            return observations, infos
 
     def step(self, actions):
         rewards = defaultdict(int)
@@ -118,9 +140,13 @@ class aec_to_parallel_wrapper(ParallelEnv):
         for agent in self.aec_env.agents:
             if agent != self.aec_env.agent_selection:
                 if self.aec_env.dones[agent]:
-                    raise AssertionError(f"expected agent {agent} got done agent {self.aec_env.agent_selection}. Parallel environment wrapper expects all agent termination (setting an agent's self.dones entry to True) to happen only at the end of a cycle.")
+                    raise AssertionError(
+                        f"expected agent {agent} got done agent {self.aec_env.agent_selection}. Parallel environment wrapper expects all agent termination (setting an agent's self.dones entry to True) to happen only at the end of a cycle."
+                    )
                 else:
-                    raise AssertionError(f"expected agent {agent} got agent {self.aec_env.agent_selection}, Parallel environment wrapper expects agents to step in a cycle.")
+                    raise AssertionError(
+                        f"expected agent {agent} got agent {self.aec_env.agent_selection}, Parallel environment wrapper expects agents to step in a cycle."
+                    )
             obs, rew, done, info = self.aec_env.last()
             self.aec_env.step(actions[agent])
             for agent in self.aec_env.agents:
@@ -128,7 +154,9 @@ class aec_to_parallel_wrapper(ParallelEnv):
 
         dones = dict(**self.aec_env.dones)
         infos = dict(**self.aec_env.infos)
-        observations = {agent: self.aec_env.observe(agent) for agent in self.aec_env.agents}
+        observations = {
+            agent: self.aec_env.observe(agent) for agent in self.aec_env.agents
+        }
         while self.aec_env.agents and self.aec_env.dones[self.aec_env.agent_selection]:
             self.aec_env.step(None)
 
@@ -150,7 +178,7 @@ class parallel_to_aec_wrapper(AECEnv):
         self.env = parallel_env
 
         self.metadata = {**parallel_env.metadata}
-        self.metadata['is_parallelizable'] = True
+        self.metadata["is_parallelizable"] = True
 
         try:
             self.possible_agents = parallel_env.possible_agents
@@ -169,19 +197,29 @@ class parallel_to_aec_wrapper(AECEnv):
 
     @property
     def observation_spaces(self):
-        warnings.warn("The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead.")
+        warnings.warn(
+            "The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead."
+        )
         try:
-            return {agent: self.observation_space(agent) for agent in self.possible_agents}
-        except AttributeError:
-            raise AttributeError("The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead")
+            return {
+                agent: self.observation_space(agent) for agent in self.possible_agents
+            }
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead"
+            ) from e
 
     @property
     def action_spaces(self):
-        warnings.warn("The `action_spaces` dictionary is deprecated. Use the `action_space` function instead.")
+        warnings.warn(
+            "The `action_spaces` dictionary is deprecated. Use the `action_space` function instead."
+        )
         try:
             return {agent: self.action_space(agent) for agent in self.possible_agents}
-        except AttributeError:
-            raise AttributeError("The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead")
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead"
+            ) from e
 
     def observation_space(self, agent):
         return self.env.observation_space(agent)
@@ -189,11 +227,8 @@ class parallel_to_aec_wrapper(AECEnv):
     def action_space(self, agent):
         return self.env.action_space(agent)
 
-    def seed(self, seed=None):
-        self.env.seed(seed)
-
-    def reset(self):
-        self._observations = self.env.reset()
+    def reset(self, seed=None, return_info=False, options=None):
+        self._observations = self.env.reset(seed=seed, options=options)
         self.agents = self.env.agents[:]
         self._live_agents = self.agents[:]
         self._actions = {agent: None for agent in self.agents}
@@ -238,7 +273,11 @@ class parallel_to_aec_wrapper(AECEnv):
 
             env_agent_set = set(self.env.agents)
 
-            self.agents = self.env.agents + [agent for agent in sorted(self._observations.keys()) if agent not in env_agent_set]
+            self.agents = self.env.agents + [
+                agent
+                for agent in sorted(self._observations.keys())
+                if agent not in env_agent_set
+            ]
 
             if len(self.env.agents):
                 self._agent_selector = agent_selector(self.env.agents)
@@ -254,7 +293,12 @@ class parallel_to_aec_wrapper(AECEnv):
     def last(self, observe=True):
         agent = self.agent_selection
         observation = self.observe(agent) if observe else None
-        return observation, self._cumulative_rewards[agent], self.dones[agent], self.infos[agent]
+        return (
+            observation,
+            self._cumulative_rewards[agent],
+            self.dones[agent],
+            self.infos[agent],
+        )
 
     def render(self, mode="human"):
         return self.env.render(mode)
@@ -266,12 +310,73 @@ class parallel_to_aec_wrapper(AECEnv):
         return str(self.env)
 
 
-class turn_based_aec_to_parallel_wrapper(aec_to_parallel_wrapper):
-    def reset(self):
-        self.aec_env.reset()
+class turn_based_aec_to_parallel_wrapper(ParallelEnv):
+    def __init__(self, aec_env):
+        self.aec_env = aec_env
+
+        try:
+            self.possible_agents = aec_env.possible_agents
+        except AttributeError:
+            pass
+
+        self.metadata = aec_env.metadata
+
+        # Not every environment has the .state_space attribute implemented
+        try:
+            self.state_space = self.aec_env.state_space
+        except AttributeError:
+            pass
+
+    @property
+    def unwrapped(self):
+        return self.aec_env.unwrapped
+
+    @property
+    def observation_spaces(self):
+        warnings.warn(
+            "The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead."
+        )
+        try:
+            return {
+                agent: self.observation_space(agent) for agent in self.possible_agents
+            }
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead"
+            ) from e
+
+    @property
+    def action_spaces(self):
+        warnings.warn(
+            "The `action_spaces` dictionary is deprecated. Use the `action_space` function instead."
+        )
+        try:
+            return {agent: self.action_space(agent) for agent in self.possible_agents}
+        except AttributeError as e:
+            raise AttributeError(
+                "The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead"
+            ) from e
+
+    def observation_space(self, agent):
+        return self.aec_env.observation_space(agent)
+
+    def action_space(self, agent):
+        return self.aec_env.action_space(agent)
+
+    def reset(self, seed=None, return_info=False, options=None):
+        self.aec_env.reset(seed=seed, return_info=return_info, options=options)
         self.agents = self.aec_env.agents[:]
-        observations = {agent: self.aec_env.observe(agent) for agent in self.aec_env.agents if not self.aec_env.dones[agent]}
-        return observations
+        observations = {
+            agent: self.aec_env.observe(agent)
+            for agent in self.aec_env.agents
+            if not self.aec_env.dones[agent]
+        }
+
+        if not return_info:
+            return observations
+        else:
+            infos = {**self.aec_env.infos}
+            return observations, infos
 
     def step(self, actions):
         if not self.agents:
@@ -280,7 +385,9 @@ class turn_based_aec_to_parallel_wrapper(aec_to_parallel_wrapper):
         rewards = {**self.aec_env.rewards}
         dones = {**self.aec_env.dones}
         infos = {**self.aec_env.infos}
-        observations = {agent: self.aec_env.observe(agent) for agent in self.aec_env.agents}
+        observations = {
+            agent: self.aec_env.observe(agent) for agent in self.aec_env.agents
+        }
 
         while self.aec_env.agents:
             if self.aec_env.dones[self.aec_env.agent_selection]:
@@ -293,3 +400,12 @@ class turn_based_aec_to_parallel_wrapper(aec_to_parallel_wrapper):
             infos[agent]["active_agent"] = self.aec_env.agent_selection
         self.agents = self.aec_env.agents
         return observations, rewards, dones, infos
+
+    def render(self, mode="human"):
+        return self.aec_env.render(mode)
+
+    def state(self):
+        return self.aec_env.state()
+
+    def close(self):
+        return self.aec_env.close()
